@@ -87,9 +87,14 @@ def init_dkms_instances(config_dict, region_info_list, credential_properties):
                     raise ValueError("init properties fail, cause of cache_client_dkms_config_info param[regionId or "
                                      "endpoint or clientKeyFile] is empty")
                 try:
-                    password = client_key_utils.get_password(config_dict, dkms_config.password_from_env_variable,
-                                                             dkms_config.password_from_file_path_name)
-                    dkms_config.password = password
+                    if dkms_config.password_from_file_path is not None \
+                            and dkms_config.password_from_file_path != "":
+                        dkms_config.password = client_key_utils.read_password_file(
+                            dkms_config.password_from_file_path)
+                    else:
+                        dkms_config.password = client_key_utils.get_password(config_dict,
+                                                                             dkms_config.password_from_env_variable,
+                                                                             dkms_config.password_from_file_path_name)
                 except(OSError, ValueError, Exception) as e:
                     if not credential_properties.password:
                         raise e
